# Table of Contents

- [servicenow-integration-faqs](<./servicenow-integration-faqs.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [ServiceNow Integration FAQs](<./ServiceNow-Integration-FAQs.md>)
  - [Integration Setup](<./ServiceNow-Integration-FAQs/Integration-Setup.md>)
  - [Data Linking and Mapping](<./ServiceNow-Integration-FAQs/Data-Linking-and-Mapping.md>)
  - [Data Synchronization](<./ServiceNow-Integration-FAQs/Data-Synchronization.md>)
  - [Data Linking and Relation Management](<./ServiceNow-Integration-FAQs/Data-Linking-and-Relation-Management.md>)
  - [Fact Sheet Management](<./ServiceNow-Integration-FAQs/Fact-Sheet-Management.md>)
  - [Lifecycle Management](<./ServiceNow-Integration-FAQs/Lifecycle-Management.md>)
  - [Tech Category Management](<./ServiceNow-Integration-FAQs/Tech-Category-Management.md>)
